%global _hardened_build 1
%{!?_iconsbasedir: %global _iconsbasedir %{_datadir}/icons/hicolor}

Name:           freedv
Version:        1.1
Release:        4%{?dist}
Summary:        FreeDV Digital Voice
License:        GPLv2+

URL:            http://freedv.org

Source0:        http://files.freedv.org/%{name}/%{name}-%{version}.tar.xz
# SpeexDSP was split out as a separate package in F22, adjust cmake packaging
# finding. Will be included in next release.
Patch0:         freedv-1.1-speexdsp.patch
# Use pre-downloaded sox first and attempt download second. Will be included
# in next release.
Patch1:         freedv-1.1-sox.patch

# Use static linking to sox 14.4.1 due to required symbol lsx_biquad_flow
# being changed to private in 14.4.2.
Source99:       sox-14.4.1.tar.gz
Source100:      freedv.appdata.xml
Source101:      freedv48x48.png
Source102:      freedv64x64.png
Source103:      freedv128x128.png
Source104:      freedv256x256.png

BuildRequires:  cmake
BuildRequires:  wxGTK3-devel
BuildRequires:  codec2-devel >= 0.5
BuildRequires:  portaudio-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libsamplerate-devel
%if 0%{?fedora} > 21
BuildRequires:  speexdsp-devel
%else
BuildRequires:  speex-devel
%endif
BuildRequires:  hamlib-devel
BuildRequires:  alsa-lib-devel
BuildRequires:  libao-devel
BuildRequires:  gsm-devel
BuildRequires:  desktop-file-utils 
BuildRequires:  libappstream-glib
# FreeDV makes use of lsx_biquad_flow which was made private in sox 14.4.2.
#BuildRequires:  sox-devel
Provides:       bundled(sox) = 14.4.1


%description
FreeDV is a GUI application for Windows and Linux that allows any SSB radio to
be used for low bit rate digital voice.

Speech is compressed down to 1400 bit/s then modulated onto a 1100 Hz wide QPSK
signal which is sent to the Mic input of a SSB radio. On receive, the signal is
received by the SSB radio, then demodulated and decoded by FreeDV.

FreeDV was built by an international team of Radio Amateurs working together on
coding, design, user interface and testing. FreeDV is open source software,
released under the GNU Public License version 2.1. The FDMDV modem and Codec 2
Speech codec used in FreeDV are also open source.


%prep
%setup -q -n freedv-%{version}
%patch0 -p1
%patch1 -p1

# Setup sox so it's found by the build system
cp %{SOURCE99} .


%build
rm -rf build_linux && mkdir build_linux && pushd build_linux
export CXXFLAGS="%{optflags} -fPIC -pie -Wl,-z,relro -Wl,-z,now"
export LDFLAGS="-Wl,--as-needed"
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DWXCONFIG="%{_bindir}/wx-config-3.0" \
       -DWXRC="%{_bindir}/wxrc-3.0" \
       -DUSE_STATIC_SOX=TRUE \
       -DUSE_STATIC_CODEC2=FALSE \
       -DUSE_STATIC_SPEEXDSP=FALSE \
       ../

make %{?_smp_mflags} VERBOSE=1


%install
pushd build_linux
%make_install

# Install desktop file
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop

# install appdata file
mkdir -p %{buildroot}%{_datadir}/appdata
install -pm 0644 %{SOURCE100} %{buildroot}%{_datadir}/appdata/
appstream-util validate-relax --nonet \
    %{buildroot}%{_datadir}/appdata/*.appdata.xml


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%{!?_licensedir:%global license %doc}
%license COPYING
%doc credits.txt README.txt
%{_bindir}/%{name}
%{_datadir}/appdata/*.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_iconsbasedir}/*/apps/%{name}.png


%changelog
* Wed Jan 20 2016 Richard Shaw <hobbes1069@gmail.com> - 1.1-4
- Create appdata file.

* Tue Dec  8 2015 Richard Shaw <hobbes1069@gmail.com> - 1.1-3
- Add sox to sources so it is not downloaded during the build.
- Add necessary build flags for RELO and PIE.

* Fri Dec  4 2015 Richard Shaw <hobbes1069@gmail.com> - 1.1-2
- Move to bundled sox to work around now private function in 14.4.2.

* Thu Sep 24 2015 Richard Shaw <hobbes1069@gmail.com> - 1.1-1
- Update to latest upstream release.

* Tue Aug 25 2015 Richard Shaw <hobbes1069@gmail.com> - 1.0-1
- Update to latest upstream release.

* Sat Jul  4 2015 Richard Shaw <hobbes1069@gmail.com> - 0.98.0-1
- Update to latest upstream release.

* Sun May 31 2015 Richard Shaw <hobbes1069@gmail.com> - 0.97.0-3
- Update to latest svn checkout.

* Tue Jun 17 2014 Richard Shaw <hobbes1069@gmail.com> - 0.97.0-1
- Update to latest upstream release.

* Sat May 24 2014 Richard Shaw <hobbes1069@gmail.com> - 0.96.7-1
- Latest release.

* Fri Mar 28 2014 Richard Shaw <hobbes1069@gmail.com> - 0.96.5-5
- Update to later svn checkout, 1481.

* Sun Mar 23 2014 Richard Shaw <hobbes1069@gmail.com> - 0.96.5-4
- Try test build with patch to remove libctb dependence.

* Sun Sep 15 2013 Richard Shaw <hobbes1069@gmail.com> - 0.96.5-3
- Update to latest checkout.

* Fri Apr 12 2013 Richard Shaw <hobbes1069@gmail.com> - 0.96-1
- Updated to lastest svn checkout (rev 1231).
- Updated spec to meet Fedora Packaging Guidelines.
- Created new icon and desktop files
- Implemented cmake based build configuration.

* Sun Dec 23 2012 Mike Heitmann <mheitmann@n0so.net> 0.91-3
- Made libctb, wxWidgets, codec2 separate rpm packages

* Sat Dec 22 2012 Mike Heitmann <mheitmann@n0so.net> 0.91-2
- Updated spec to use %%{_libdir} and %%{_bindir} macros

* Sun Dec 16 2012 Mike Heitmann <mheitmann@n0so.net> 0.91-1
- Initial SPEC

